@@ -19,16 +19,19 @@
 
 #' Do column data agree with a predicate expression?
 #'
-#' The `col_vals_expr()` validation function checks for whether column values in
-#' a table match a user-defined predicate expression. The validation function
-#' can be used directly on a data table or with an *agent* object (technically,
-#' a `ptblank_agent` object) whereas the expectation and test functions can only
-#' be used with a data table. The types of data tables that can be used include
-#' data frames, tibbles, database tables (`tbl_dbi`), and Spark DataFrames
-#' (`tbl_spark`). Each validation step or expectation will operate over the
-#' number of test units that is equal to the number of rows in the table (after
-#' any `preconditions` have been applied).
+#' @description
+#' The `col_vals_expr()` validation function, the `expect_col_vals_expr()`
+#' expectation function, and the `test_col_vals_expr()` test function all check
+#' whether column values in a table agree with a user-defined predicate
+#' expression. The validation function can be used directly on a data table or
+#' with an *agent* object (technically, a `ptblank_agent` object) whereas the
+#' expectation and test functions can only be used with a data table. The types
+#' of data tables that can be used include data frames, tibbles, database tables
+#' (`tbl_dbi`), and Spark DataFrames (`tbl_spark`). Each validation step or
+#' expectation will operate over the number of test units that is equal to the
+#' number of rows in the table (after any `preconditions` have been applied).
 #' 
+#' @section Preconditions:
 #' Having table `preconditions` means **pointblank** will mutate the table just
 #' before interrogation. Such a table mutation is isolated in scope to the
 #' validation step(s) produced by the validation function call. Using
@@ -40,6 +43,7 @@
 #' instead be supplied (e.g., 
 #' `function(x) dplyr::mutate(x, col_a = col_b + 10)`).
 #' 
+#' @section Actions:
 #' Often, we will want to specify `actions` for the validation. This argument,
 #' present in every validation function, takes a specially-crafted list
 #' object that is best produced by the [action_levels()] function. Read that
@@ -54,11 +58,52 @@
 #' quarter of the total test units fails, the other `stop()`s at the same
 #' threshold level).
 #' 
+#' @section Briefs:
 #' Want to describe this validation step in some detail? Keep in mind that this
 #' is only useful if `x` is an *agent*. If that's the case, `brief` the agent
 #' with some text that fits. Don't worry if you don't want to do it. The
 #' *autobrief* protocol is kicked in when `brief = NULL` and a simple brief will
 #' then be automatically generated.
+#' 
+#' @section YAML:
+#' A **pointblank** agent can be written to YAML with [yaml_write()] and the
+#' resulting YAML can be used to regenerate an agent (with [yaml_read_agent()])
+#' or interrogate the target table (via [yaml_agent_interrogate()]). When
+#' `col_vals_expr()` is represented in YAML (under the top-level `steps` key as
+#' a list member), the syntax closely follows the signature of the validation
+#' function. Here is an example of how a complex call of `col_vals_expr()` as a
+#' validation step is expressed in R code and in the corresponding YAML
+#' representation.
+#' 
+#' ```
+#' # R statement
+#' agent %>% 
+#'   col_vals_expr(
+#'     expr = ~ a %% 1 == 0,
+#'     preconditions = ~ . %>% dplyr::filter(a < 10),
+#'     actions = action_levels(warn_at = 0.1, stop_at = 0.2),
+#'     label = "The `col_vals_expr()` step.",
+#'     active = FALSE
+#'   )
+#' 
+#' # YAML representation
+#' steps:
+#' - col_vals_expr:
+#'     expr: ~a%%1 == 0
+#'     preconditions: ~. %>% dplyr::filter(a < 10)
+#'     actions:
+#'       warn_fraction: 0.1
+#'       stop_fraction: 0.2
+#'     label: The `col_vals_expr()` step.
+#'     active: false
+#' ```
+#' 
+#' In practice, both of these will often be shorter as only the `expr` argument
+#' requires a value. Arguments with default values won't be written to YAML when
+#' using [yaml_write()] (though it is acceptable to include them with their
+#' default when generating the YAML by other means). It is also possible to
+#' preview the transformation of an agent to YAML without any writing to disk by
+#' using the [yaml_agent_string()] function.
 #'   
 #' @inheritParams col_vals_gt
 #' @param expr An expression to use for this test. This can either be in the
@@ -160,7 +205,11 @@
 #' 
 #' @family validation functions
 #' @section Function ID:
-#' 2-25
+#' 2-18
+#' 
+#' @seealso These reexported functions (from **rlang** and **dplyr**) work
+#'   nicely within `col_vals_expr()` and its variants: [rlang::expr()],
+#'   [dplyr::between()], and [dplyr::case_when()].
 #' 
 #' @name col_vals_expr
 NULL
@@ -219,6 +268,9 @@ col_vals_expr <- function(x,
   # Normalize any provided `step_id` value(s)
   step_id <- normalize_step_id(step_id, columns = "column", agent)
   
+  # Get the next step number for the `validation_set` tibble
+  i_o <- get_next_validation_set_row(agent)
+  
   # Check `step_id` value(s) against all other `step_id`
   # values in earlier validation steps
   check_step_id_duplicates(step_id, agent)
@@ -228,6 +280,8 @@ col_vals_expr <- function(x,
     create_validation_step(
       agent = agent,
       assertion_type = "col_vals_expr",
+      i_o = i_o,
+      columns_expr = NA_character_,
       column = NA_character_,
       values = expr,
       preconditions = preconditions,
