@@ -19,6 +19,7 @@
 
 #' Are data not part of a specified set of values?
 #'
+#' @description
 #' The `col_vals_not_in_set()` validation function, the
 #' `expect_col_vals_not_in_set()` expectation function, and the
 #' `test_col_vals_not_in_set()` test function all check whether column values in
@@ -31,6 +32,7 @@
 #' operate over the number of test units that is equal to the number of rows in
 #' the table (after any `preconditions` have been applied).
 #'
+#' @section Column Names:
 #' If providing multiple column names, the result will be an expansion of
 #' validation steps to that number of column names (e.g., `vars(col_a, col_b)`
 #' will result in the entry of two validation steps). Aside from column names in
@@ -38,6 +40,7 @@
 #' specifying columns. They are: `starts_with()`, `ends_with()`, `contains()`,
 #' `matches()`, and `everything()`.
 #' 
+#' @section Preconditions:
 #' Having table `preconditions` means **pointblank** will mutate the table just
 #' before interrogation. Such a table mutation is isolated in scope to the
 #' validation step(s) produced by the validation function call. Using
@@ -49,6 +52,7 @@
 #' instead be supplied (e.g., 
 #' `function(x) dplyr::mutate(x, col_a = col_b + 10)`).
 #' 
+#' @section Actions:
 #' Often, we will want to specify `actions` for the validation. This argument,
 #' present in every validation function, takes a specially-crafted list object
 #' that is best produced by the [action_levels()] function. Read that function's
@@ -63,12 +67,59 @@
 #' quarter of the total test units fails, the other `stop()`s at the same
 #' threshold level).
 #' 
+#' @section Briefs:
 #' Want to describe this validation step in some detail? Keep in mind that this
 #' is only useful if `x` is an *agent*. If that's the case, `brief` the agent
 #' with some text that fits. Don't worry if you don't want to do it. The
 #' *autobrief* protocol is kicked in when `brief = NULL` and a simple brief will
 #' then be automatically generated.
 #' 
+#' @section YAML:
+#' A **pointblank** agent can be written to YAML with [yaml_write()] and the
+#' resulting YAML can be used to regenerate an agent (with [yaml_read_agent()])
+#' or interrogate the target table (via [yaml_agent_interrogate()]). When
+#' `col_vals_not_in_set()` is represented in YAML (under the top-level `steps`
+#' key as a list member), the syntax closely follows the signature of the
+#' validation function. Here is an example of how a complex call of
+#' `col_vals_not_in_set()` as a validation step is expressed in R code and in
+#' the corresponding YAML representation.
+#' 
+#' ```
+#' # R statement
+#' agent %>% 
+#'   col_vals_not_in_set(
+#'     columns = vars(a),
+#'     set = c(1, 2, 3, 4),
+#'     preconditions = ~ . %>% dplyr::filter(a < 10),
+#'     actions = action_levels(warn_at = 0.1, stop_at = 0.2),
+#'     label = "The `col_vals_not_in_set()` step.",
+#'     active = FALSE
+#'   )
+#' 
+#' # YAML representation
+#' steps:
+#' - col_vals_not_in_set:
+#'     columns: vars(a)
+#'    set:
+#'    - 1.0
+#'    - 2.0
+#'    - 3.0
+#'    - 4.0
+#'    preconditions: ~. %>% dplyr::filter(a < 10)
+#'    actions:
+#'      warn_fraction: 0.1
+#'      stop_fraction: 0.2
+#'    label: The `col_vals_not_in_set()` step.
+#'    active: false
+#' ```
+#' 
+#' In practice, both of these will often be shorter as only the `columns`, and
+#' `set` arguments require values. Arguments with default values won't be
+#' written to YAML when using [yaml_write()] (though it is acceptable to include
+#' them with their default when generating the YAML by other means). It is also
+#' possible to preview the transformation of an agent to YAML without any
+#' writing to disk by using the [yaml_agent_string()] function.
+#' 
 #' @inheritParams col_vals_gt
 #' @param set A vector of numeric or string-based elements, where column values
 #'   found within this `set` will be considered as failing.
@@ -167,6 +218,11 @@ col_vals_not_in_set <- function(x,
                                 brief = NULL,
                                 active = TRUE) {
   
+  # Get `columns` as a label
+  columns_expr <- 
+    rlang::as_label(rlang::quo(!!enquo(columns))) %>%
+    gsub("^\"|\"$", "", .)
+  
   # Capture the `columns` expression
   columns <- rlang::enquo(columns)
   
@@ -207,6 +263,9 @@ col_vals_not_in_set <- function(x,
   # Normalize any provided `step_id` value(s)
   step_id <- normalize_step_id(step_id, columns, agent)
   
+  # Get the next step number for the `validation_set` tibble
+  i_o <- get_next_validation_set_row(agent)
+  
   # Check `step_id` value(s) against all other `step_id`
   # values in earlier validation steps
   check_step_id_duplicates(step_id, agent)
@@ -219,6 +278,8 @@ col_vals_not_in_set <- function(x,
       create_validation_step(
         agent = agent,
         assertion_type = "col_vals_not_in_set",
+        i_o = i_o,
+        columns_expr = columns_expr,
         column = columns[i],
         values = set,
         preconditions = preconditions,
