@@ -1,3 +1,22 @@
+#
+#                _         _    _      _                _    
+#               (_)       | |  | |    | |              | |   
+#  _ __    ___   _  _ __  | |_ | |__  | |  __ _  _ __  | | __
+# | '_ \  / _ \ | || '_ \ | __|| '_ \ | | / _` || '_ \ | |/ /
+# | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   < 
+# | .__/  \___/ |_||_| |_| \__||_.__/ |_| \__,_||_| |_||_|\_\
+# | |                                                        
+# |_|                                                        
+# 
+# This file is part of the 'rich-iannone/pointblank' package.
+# 
+# (c) Richard Iannone <riannone@me.com>
+# 
+# For full copyright and license information, please look at
+# https://rich-iannone.github.io/pointblank/LICENSE.html
+#
+
+
 #' Enable logging of failure conditions at the validation step level
 #' 
 #' The `log4r_step()` function can be used as an action in the [action_levels()]
@@ -22,11 +41,22 @@
 #' @param append_to The file to which log entries at the warn level are
 #'   appended. This can alternatively be one or more **log4r** appenders.
 #' 
+#' @family Logging
+#' @section Function ID:
+#' 5-1
+#' 
 #' @export
 log4r_step <- function(x,
                        message = NULL,
                        append_to = "pb_log_file") {
   
+  if (!requireNamespace("log4r", quietly = TRUE)) {
+    stop("Using the `log4r_step()` function requires ", 
+         "the log4r package:\n",
+         " * It can be installed with `install.packages(\"log4r\")`.",
+         call. = FALSE)
+  }
+  
   # nocov start
   
   type <- x$this_type
