@@ -62,6 +62,8 @@ utils::globalVariables(
     "color",
     "column",
     "columns",
+    "columns_expr",
+    "col_element",
     "col_name",
     "condition",
     "count",
@@ -72,20 +74,26 @@ utils::globalVariables(
     "desc",
     "duplicates",
     "extract",
+    "eval_active",
     "eval_error",
     "eval_pts",
     "eval_sym",
     "eval_warning",
     "f_fail",
+    "f_failed",
     "f_pass",
     "f_passed",
+    "file_name",
     "Freq",
     "frequency",
     "Frequency",
+    "head.ref",
     "i",
     "item",
+    "i_o",
     "label",
     "::labels::",
+    "merge_commit_sha",
     "n",
     "n_fail",
     "n_pass",
@@ -94,9 +102,13 @@ utils::globalVariables(
     "N_pts",
     "N_val",
     "notify",
+    "number",
     ".panel_x",
     ".panel_y",
     "pb_is_good_",
+    "pb_is_good_1_",
+    "pb_is_good_2_",
+    "pb_lagged_difference_",
     "pct",
     "precon",
     "preconditions",
@@ -108,16 +120,21 @@ utils::globalVariables(
     "S",
     "schema",
     "sd",
+    "set_element",
     "S_pts",
     "S_val",
+    "sha1",
     "status_color",
+    "step_id",
     "tbl_checked",
+    "time_str",
     "total_pts",
     "type",
     "value",
     "values",
     "Var1",
     "Var2",
+    "view",
     "W",
     "W_pts",
     "W_val",
