@@ -1,3 +1,5 @@
+skip_on_cran()
+
 tbl <- 
   small_table %>%
   dplyr::mutate(g = as.factor(f))
@@ -9,6 +11,22 @@ tbl_conjointly <-
     c = c(2, 6, 8, NA, 3, 8)
   )
 
+increasing_tbl <-
+  dplyr::tibble(
+    a = c(5, 6, 7, 8, 9, 12),
+    b = c(1, 2, NA,3, 4, 5),
+    c = c(1, 2, 2, 4, 5, 7),
+    d = c(1, 2, 1.9999, 4, 5, 7)
+  )
+
+decreasing_tbl <-
+  dplyr::tibble(
+    a = c(12, 9, 8, 7, 6, 5),
+    b = c(6, 5, NA,4, 3, 1),
+    c = c(7, 5, 5, 4, 2, 1),
+    d = c(7, 5, 4, 4.0001, 3, 1)
+  )
+
 tbl_equal_c_3 <- tbl %>% dplyr::filter(c == 3)
 tbl_not_equal_c_3 <- tbl %>% dplyr::filter(c != 3)
 tbl_c_null <- tbl %>% dplyr::filter(is.na(c))
@@ -17,7 +35,7 @@ tbl_c_not_null <- tbl %>% dplyr::filter(!is.na(c))
 test_that("pointblank expectation functions produce the correct results", {
 
   #
-  # test_col_vals_lt
+  # test_col_vals_lt()
   #
   
   expect_true(test_col_vals_lt(tbl, columns = vars(d), value = 11000))
@@ -28,7 +46,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_vals_lt(tbl, columns = vars(d), value = 9900, threshold = 0.01))
   
   #
-  # test_col_vals_lte
+  # test_col_vals_lte()
   #
   
   expect_true(test_col_vals_lte(tbl, columns = vars(a), value = 8))
@@ -39,7 +57,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_vals_lte(tbl, columns = vars(a), value = 7, threshold = 0.01))
   
   #
-  # test_col_vals_equal
+  # test_col_vals_equal()
   #
   
   expect_true(test_col_vals_equal(tbl_equal_c_3, columns = vars(c), value = 3))
@@ -50,7 +68,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_vals_equal(tbl_equal_c_3, columns = vars(c), value = 7, threshold = 0.01))
   
   #
-  # test_col_vals_not_equal
+  # test_col_vals_not_equal()
   #
   
   expect_true(test_col_vals_not_equal(tbl_not_equal_c_3, columns = vars(c), value = 3))
@@ -61,7 +79,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_vals_not_equal(tbl_not_equal_c_3, columns = vars(c), value = 7, threshold = 0.01))
   
   #
-  # test_col_vals_gte
+  # test_col_vals_gte()
   #
   
   expect_true(test_col_vals_gte(tbl, columns = vars(c), value = 0, na_pass = TRUE))
@@ -73,7 +91,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_vals_gte(tbl, columns = vars(c), value = 0, threshold = 0.01))
 
   #
-  # test_col_vals_gt
+  # test_col_vals_gt()
   #
   
   expect_true(test_col_vals_gt(tbl, columns = vars(a), value = 1, threshold = 2))
@@ -85,7 +103,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_vals_gt(tbl, columns = vars(c), value = 0, threshold = 0.01))
 
   #
-  # test_col_vals_between
+  # test_col_vals_between()
   #
   
   expect_true(test_col_vals_between(tbl, columns = vars(d), left = 0, right = 9000, threshold = 2))
@@ -98,7 +116,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_vals_between(tbl, columns = vars(d), left = 0, right = 500, threshold = 0.01))
 
   #
-  # test_col_vals_not_between
+  # test_col_vals_not_between()
   #
   
   expect_true(test_col_vals_not_between(tbl, columns = vars(d), left = 0, right = 9000, threshold = 100))
@@ -111,7 +129,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_vals_not_between(tbl, columns = vars(c), left = 20, right = 30, threshold = 0.01))
 
   #
-  # test_col_vals_in_set
+  # test_col_vals_in_set()
   #
   
   expect_true(test_col_vals_in_set(tbl, columns = vars(b), set = tbl$b))
@@ -122,7 +140,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_vals_in_set(tbl, columns = vars(e), set = TRUE, threshold = 0.01))
 
   #
-  # test_col_vals_not_in_set
+  # test_col_vals_not_in_set()
   #
   
   expect_false(test_col_vals_not_in_set(tbl, columns = vars(b), set = tbl$b))
@@ -133,7 +151,67 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_vals_not_in_set(tbl, columns = vars(b), set = tbl$b, threshold = 0.01))
 
   #
-  # test_col_vals_null
+  # expect_col_vals_make_set()
+  #
+  
+  expect_true(test_col_vals_make_set(tbl, columns = vars(c), set = tbl$c %>% unique()))
+  expect_true(test_col_vals_make_set(tbl, columns = vars(c), set = tbl$c))
+  expect_true(test_col_vals_make_set(tbl, columns = vars(b), set = tbl$b))
+  expect_true(test_col_vals_make_set(tbl, columns = vars(c), set = c(2, 3, 4, 7, 9, NA), threshold = 3))
+  expect_false(test_col_vals_make_set(tbl, columns = vars(c), set = c(2, 3, 4, 7, 9, NA)))
+  expect_false(test_col_vals_make_set(tbl, columns = vars(e), set = TRUE))
+  
+  
+  #
+  # expect_col_vals_make_subset()
+  #
+  
+  expect_true(test_col_vals_make_subset(tbl, columns = vars(c), set = tbl$c %>% unique()))
+  expect_true(test_col_vals_make_subset(tbl, columns = vars(c), set = tbl$c))
+  expect_true(test_col_vals_make_subset(tbl, columns = vars(b), set = tbl$b))
+  expect_true(test_col_vals_make_subset(tbl, columns = vars(c), set = c(3, 8)))
+  expect_true(test_col_vals_make_subset(tbl, columns = vars(c), set = c(2, 3, 4, 7, 9, NA), threshold = 3))
+  expect_false(test_col_vals_make_subset(tbl, columns = vars(c), set = c(99, 2, 3, 4, 7, 9, NA)))
+  expect_false(test_col_vals_make_subset(tbl, columns = vars(e), set = ""))
+  
+  #
+  # expect_col_vals_increasing()
+  #
+  
+  expect_true(test_col_vals_increasing(increasing_tbl, vars(a)))
+  expect_true(test_col_vals_increasing(increasing_tbl, vars(b), na_pass = TRUE))
+  expect_true(test_col_vals_increasing(increasing_tbl, vars(c), allow_stationary = TRUE))
+  expect_true(test_col_vals_increasing(increasing_tbl, vars(d), decreasing_tol = 0.001))
+  expect_true(test_col_vals_increasing(increasing_tbl, vars(d), decreasing_tol = 0.0001))
+  expect_true(test_col_vals_increasing(increasing_tbl, vars(d), allow_stationary = TRUE, decreasing_tol = 0.001))
+  expect_false(test_col_vals_increasing(increasing_tbl, vars(d), allow_stationary = TRUE, decreasing_tol = 0.00001))
+  expect_false(test_col_vals_increasing(increasing_tbl, vars(b)))
+  expect_false(test_col_vals_increasing(increasing_tbl, vars(c)))
+  expect_false(test_col_vals_increasing(increasing_tbl, vars(d), allow_stationary = TRUE))
+  expect_false(test_col_vals_increasing(increasing_tbl, vars(d), decreasing_tol = 0.00001))
+  expect_false(test_col_vals_increasing(increasing_tbl, vars(b), threshold = 1))
+  expect_false(test_col_vals_increasing(increasing_tbl, vars(b), threshold = 0.01))
+  
+  #
+  # expect_col_vals_decreasing()
+  #
+  
+  expect_true(test_col_vals_decreasing(decreasing_tbl, vars(a)))
+  expect_true(test_col_vals_decreasing(decreasing_tbl, vars(b), na_pass = TRUE))
+  expect_true(test_col_vals_decreasing(decreasing_tbl, vars(c), allow_stationary = TRUE))
+  expect_true(test_col_vals_decreasing(decreasing_tbl, vars(d), increasing_tol = 0.001))
+  expect_true(test_col_vals_decreasing(decreasing_tbl, vars(d), increasing_tol = 0.0001))
+  expect_true(test_col_vals_decreasing(decreasing_tbl, vars(d), allow_stationary = TRUE, increasing_tol = 0.001))
+  expect_false(test_col_vals_decreasing(decreasing_tbl, vars(d), allow_stationary = TRUE, increasing_tol = 0.00001))
+  expect_false(test_col_vals_decreasing(decreasing_tbl, vars(b)))
+  expect_false(test_col_vals_decreasing(decreasing_tbl, vars(c)))
+  expect_false(test_col_vals_decreasing(decreasing_tbl, vars(d), allow_stationary = TRUE))
+  expect_false(test_col_vals_decreasing(decreasing_tbl, vars(d), increasing_tol = 0.00001))
+  expect_false(test_col_vals_decreasing(decreasing_tbl, vars(b), threshold = 1))
+  expect_false(test_col_vals_decreasing(decreasing_tbl, vars(b), threshold = 0.01))
+  
+  #
+  # test_col_vals_null()
   #
   
   expect_true(test_col_vals_null(tbl_c_null, columns = vars(c)))
@@ -144,7 +222,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_vals_null(tbl_c_not_null, columns = vars(c), threshold = 0.01))
 
   #
-  # test_col_vals_not_null
+  # test_col_vals_not_null()
   #
   
   expect_true(test_col_vals_not_null(tbl_c_not_null, columns = vars(c)))
@@ -153,9 +231,9 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_true(test_col_vals_not_null(tbl, columns = vars(c), threshold = 1000))
   expect_false(test_col_vals_not_null(tbl_c_null, columns = vars(c), threshold = 1))
   expect_false(test_col_vals_not_null(tbl_c_null, columns = vars(c), threshold = 0.01))
-
+  
   #
-  # test_col_vals_regex
+  # test_col_vals_regex()
   #
   
   expect_true(test_col_vals_regex(tbl, vars(b), regex = "^[0-9]-[a-z]{3}-[0-9]{3}$"))
@@ -165,7 +243,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_vals_regex(tbl, vars(b), regex = "^[0-9]-[a-z]{4}-[0-9]{3}$", threshold = 0.01))
   
   #
-  # test_col_vals_expr
+  # test_col_vals_expr()
   #
   
   expect_true(test_col_vals_expr(tbl, ~ a %% 1 == 0))
@@ -192,7 +270,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_vals_expr(tbl, expr(between(a, 5, 10)), threshold = 0.01))
 
   #
-  # test_conjointly
+  # test_conjointly()
   #
   
   expect_true(
@@ -237,7 +315,7 @@ test_that("pointblank expectation functions produce the correct results", {
   )
   
   #
-  # test_rows_distinct
+  # test_rows_distinct()
   #
   
   expect_true(test_rows_distinct(tbl %>% dplyr::select(d) %>% dplyr::slice(5)))
@@ -247,7 +325,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_rows_distinct(tbl, threshold = 0.01))
 
   #
-  # test_col_is_character
+  # test_col_is_character()
   #
   
   expect_false(test_col_is_character(tbl, columns = vars(date_time)))
@@ -262,7 +340,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_is_character(tbl, columns = vars(g), threshold = 0.01))
 
   #
-  # test_col_is_numeric
+  # test_col_is_numeric()
   #
   
   expect_false(test_col_is_numeric(tbl, columns = vars(date_time)))
@@ -277,7 +355,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_is_numeric(tbl, columns = vars(g), threshold = 0.01))
 
   #
-  # test_col_is_integer
+  # test_col_is_integer()
   #
 
   expect_false(test_col_is_integer(tbl, columns = vars(date_time)))
@@ -292,7 +370,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_is_integer(tbl, columns = vars(g), threshold = 0.01))
 
   #
-  # test_col_is_posix
+  # test_col_is_posix()
   #
 
   expect_false(test_col_is_posix(tbl, columns = vars(date)))
@@ -307,7 +385,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_is_posix(tbl, columns = vars(g), threshold = 0.01))
 
   #
-  # test_col_is_logical
+  # test_col_is_logical()
   #
   
   expect_false(test_col_is_logical(tbl, columns = vars(date_time)))
@@ -322,7 +400,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_is_logical(tbl, columns = vars(g), threshold = 0.01))
 
   #
-  # test_col_is_date
+  # test_col_is_date()
   #
 
   expect_false(test_col_is_date(tbl, columns = vars(date_time)))
@@ -337,7 +415,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_is_date(tbl, columns = vars(g), threshold = 0.01))
 
   #
-  # test_col_is_factor
+  # test_col_is_factor()
   #
   
   expect_false(test_col_is_factor(tbl, columns = vars(date_time)))
@@ -352,7 +430,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_is_factor(tbl, columns = vars(f), threshold = 0.01))
 
   #
-  # test_col_exists
+  # test_col_exists()
   #
   
   expect_true(test_col_exists(tbl, columns = vars(date_time)))
@@ -370,7 +448,7 @@ test_that("pointblank expectation functions produce the correct results", {
   expect_false(test_col_exists(tbl, columns = vars(h), threshold = 0.01))
   
   #
-  # test_col_schema_match
+  # test_col_schema_match()
   #
   
   expect_true(
